@@ -11,6 +11,7 @@ from SoftLayer.managers.block import BlockStorageManager
 from SoftLayer.managers.cdn import CDNManager
 from SoftLayer.managers.dedicated_host import DedicatedHostManager
 from SoftLayer.managers.dns import DNSManager
+from SoftLayer.managers.event_log import EventLogManager
 from SoftLayer.managers.file import FileStorageManager
 from SoftLayer.managers.firewall import FirewallManager
 from SoftLayer.managers.hardware import HardwareManager
@@ -27,13 +28,16 @@ from SoftLayer.managers.ssl import SSLManager
 from SoftLayer.managers.ticket import TicketManager
 from SoftLayer.managers.user import UserManager
 from SoftLayer.managers.vs import VSManager
-
+from SoftLayer.managers.vs_capacity import CapacityManager
+from SoftLayer.managers.vs_placement import PlacementManager
 
 __all__ = [
     'BlockStorageManager',
+    'CapacityManager',
     'CDNManager',
     'DedicatedHostManager',
     'DNSManager',
+    'EventLogManager',
     'FileStorageManager',
     'FirewallManager',
     'HardwareManager',
@@ -45,6 +49,7 @@ __all__ = [
     'NetworkManager',
     'ObjectStorageManager',
     'OrderingManager',
+    'PlacementManager',
     'SshKeyManager',
     'SSLManager',
     'TicketManager',
