@@ -580,3 +580,15 @@ class ServerCLITests(testing.TestCase):
         result = self.run_command(['hw', 'ready', '100', '--wait=100'])
         self.assert_no_fail(result)
         self.assertEqual(result.output, '"READY"\n')
+
+    def test_toggle_ipmi_on(self):
+        mock.return_value = True
+        result = self.run_command(['server', 'toggle-ipmi', '--enable', '12345'])
+        self.assert_no_fail(result)
+        self.assertEqual(result.output, 'True\n')
+
+    def test_toggle_ipmi_off(self):
+        mock.return_value = True
+        result = self.run_command(['server', 'toggle-ipmi', '--disable', '12345'])
+        self.assert_no_fail(result)
+        self.assertEqual(result.output, 'True\n')
